@@ -3,10 +3,10 @@
 {
     'name': 'Account',
     'name_de_DE': 'Buchhaltung',
-    'name_fr_FR': 'Comptabilité',
     'name_es_CO': 'Contabilidad',
     'name_es_ES': 'Contabilidad',
-    'version': '1.2.7',
+    'name_fr_FR': 'Comptabilité',
+    'version': '1.4.4',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -41,22 +41,6 @@ Zugehörige Berichte:
     - Offene Posten
     - Fälligkeitsliste
     - Allgemeines Journal
-''',
-    'description_fr_FR': '''Module financier et comptable avec:
-    - Comptabilité générale
-    - Gestion des années fiscales
-    - Gestion des taxes
-    - Journaux d'entrées
-    - Réconciliation
-
-Et les rapports:
-    - Grand livre
-    - Balance
-    - Bilan
-    - Compte des résultats
-    - Balance des tiers
-    - Balance agée
-    - Journal général
 ''',
     'description_es_CO': '''El módulo Financiero y de Contabilidad cuenta con:
     - Contabilidad General
@@ -74,21 +58,37 @@ Y con los reportes:
     - Saldos Vencidos
     - Diario general
 ''',
-    'description_es_ES': '''El módulo Financiero y de Contabilidad cuenta con:
+    'description_es_ES': '''Módulo financiero y de contabilidad con:
     - Contabilidad General
-    - Manejo de Años Fiscales
-    - Administración de impuestos
+    - Gestión de ejercicios fiscales
+    - Gestión de impuestos
     - Libros diarios
     - Conciliación
 
-Y con los reportes:
-    - Libro general
-    - Balance de prueba
-    - Hoja de Balance
-    - Estado de Ingresos
-    - Balance de Terceros
-    - Saldos Vencidos
-    - Diario general
+Y con los informes:
+    - Libro mayor
+    - Balance de sumas y saldos
+    - Balance general
+    - Estado de pérdidas y ganancias
+    - Balance de un Tercero
+    - Saldo Vencido
+    - Libro diario
+''',
+    'description_fr_FR': '''Module financier et comptable avec:
+    - Comptabilité générale
+    - Gestion des années fiscales
+    - Gestion des taxes
+    - Journaux d'entrées
+    - Réconciliation
+
+Et les rapports:
+    - Grand livre
+    - Balance
+    - Bilan
+    - Compte des résultats
+    - Balance des tiers
+    - Balance agée
+    - Journal général
 ''',
     'depends': [
         'ir',
@@ -107,9 +107,9 @@ Y con los reportes:
         'party.xml',
     ],
     'translation': [
-        'fr_FR.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
+        'fr_FR.csv',
     ],
 }
