@@ -4,6 +4,7 @@
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.report import Report
+from trytond.tools import reduce_ids
 from decimal import Decimal
 import datetime
 import time
@@ -559,8 +560,8 @@ class Account(ModelSQL, ModelView):
     debit = fields.Function('get_credit_debit', digits="(16, currency_digits)",
             string='Debit', depends=['currency_digits'])
     reconcile = fields.Boolean('Reconcile',
-            help='Check if the account can be used \n' \
-                    'for reconciliation.',
+            help='Allow move lines of this account \n' \
+                    'to be reconciled.',
             states={
                 'invisible': "kind == 'view'",
             }, depends=['kind'])
@@ -666,6 +667,9 @@ class Account(ModelSQL, ModelView):
                 'GROUP BY a.id', args_ids)
         account_sum = {}
         for account_id, sum in cursor.fetchall():
+            # SQLite uses float for SUM
+            if not isinstance(sum, Decimal):
+                sum = Decimal(str(sum))
             account_sum[account_id] = sum
 
         account2company = {}
@@ -774,22 +778,26 @@ class Account(ModelSQL, ModelView):
                 context=context)
         for i in range(0, len(ids), cursor.IN_MAX):
             sub_ids = ids[i:i + cursor.IN_MAX]
+            red_sql, red_ids = reduce_ids('a.id', sub_ids)
             cursor.execute('SELECT a.id, ' + \
-                        ','.join(['SUM(COALESCE(l.' + name + ', 0))'
-                            for name in names]) + ' ' \
+                        ','.join('SUM(COALESCE(l.' + name + ', 0))'
+                            for name in names) + ' ' \
                     'FROM account_account a ' \
                         'LEFT JOIN account_move_line l ' \
                         'ON (a.id = l.account) ' \
                     'WHERE a.kind != \'view\' ' \
-                        'AND a.id IN (' + \
-                            ','.join(['%s' for x in sub_ids]) + ') ' \
+                        'AND ' + red_sql + ' ' \
                         'AND ' + line_query + ' ' \
                         'AND a.active ' \
-                    'GROUP BY a.id', sub_ids)
+                    'GROUP BY a.id', red_ids)
             for row in cursor.fetchall():
                 account_id = row[0]
                 for i in range(len(names)):
-                    res[names[i]][account_id] = row[i + 1]
+                    # SQLite uses float for SUM
+                    if not isinstance(row[i + 1], Decimal):
+                        res[names[i]][account_id] = Decimal(str(row[i + 1]))
+                    else:
+                        res[names[i]][account_id] = row[i + 1]
 
         account2company = {}
         id2company = {}
@@ -1151,11 +1159,11 @@ class PrintGeneralLegderInit(ModelView):
     fiscalyear = fields.Many2One('account.fiscalyear', 'Fiscal Year',
             required=True, on_change=['fiscalyear'])
     start_period = fields.Many2One('account.period', 'Start Period',
-            domain="[('fiscalyear', '=', fiscalyear), " \
-                    "('start_date', '<=', (end_period, 'start_date'))]")
+            domain=["('fiscalyear', '=', fiscalyear)",
+                "('start_date', '<=', (end_period, 'start_date'))"])
     end_period = fields.Many2One('account.period', 'End Period',
-            domain="[('fiscalyear', '=', fiscalyear), " \
-                    "('start_date', '>=', (start_period, 'start_date'))]")
+            domain=["('fiscalyear', '=', fiscalyear)",
+                    "('start_date', '>=', (start_period, 'start_date'))"])
     company = fields.Many2One('company.company', 'Company', required=True)
     posted = fields.Boolean('Posted Move', help='Show only posted move')
     empty_account = fields.Boolean('Empty Account',
@@ -1362,12 +1370,12 @@ class PrintTrialBalanceInit(ModelView):
             required=True, on_change=['fiscalyear'],
             depends=['start_period', 'end_period'])
     start_period = fields.Many2One('account.period', 'Start Period',
-            domain="[('fiscalyear', '=', fiscalyear), " \
-                    "('start_date', '<=', (end_period, 'start_date'))]",
+            domain=["('fiscalyear', '=', fiscalyear)",
+                "('start_date', '<=', (end_period, 'start_date'))"],
             depends=['end_period'])
     end_period = fields.Many2One('account.period', 'End Period',
-            domain="[('fiscalyear', '=', fiscalyear), " \
-                    "('start_date', '>=', (start_period, 'start_date'))]",
+            domain=["('fiscalyear', '=', fiscalyear)",
+                "('start_date', '>=', (start_period, 'start_date'))"],
             depends=['start_period'])
     company = fields.Many2One('company.company', 'Company', required=True)
     posted = fields.Boolean('Posted Move', help='Show only posted move')
@@ -1616,12 +1624,12 @@ class OpenIncomeStatementInit(ModelView):
             required=True, on_change=['fiscalyear'],
             depends=['start_period', 'end_period'])
     start_period = fields.Many2One('account.period', 'Start Period',
-            domain="[('fiscalyear', '=', fiscalyear), " \
-                    "('start_date', '<=', (end_period, 'start_date'))]",
+            domain=["('fiscalyear', '=', fiscalyear)",
+                "('start_date', '<=', (end_period, 'start_date'))"],
             depends=['end_period'])
     end_period = fields.Many2One('account.period', 'End Period',
-            domain="[('fiscalyear', '=', fiscalyear), " \
-                    "('start_date', '>=', (start_period, 'start_date'))]",
+            domain=["('fiscalyear', '=', fiscalyear)",
+                "('start_date', '>=', (start_period, 'start_date'))"],
             depends=['start_period'])
     company = fields.Many2One('company.company', 'Company', required=True)
     posted = fields.Boolean('Posted Move', help='Show only posted move')
@@ -1758,11 +1766,11 @@ class CreateChartAccountPropertites(ModelView):
     company = fields.Many2One('company.company', 'Company')
     account_receivable = fields.Many2One('account.account',
             'Default Receivable Account',
-            domain="[('kind', '=', 'receivable'), ('company', '=', company)]",
+            domain=[('kind', '=', 'receivable'), "('company', '=', company)"],
             depends=['company'])
     account_payable = fields.Many2One('account.account',
             'Default Payable Account',
-            domain="[('kind', '=', 'payable'), ('company', '=', company)]",
+            domain=[('kind', '=', 'payable'), "('company', '=', company)"],
             depends=['company'])
 
 CreateChartAccountPropertites()
@@ -1944,12 +1952,20 @@ class UpdateChartAccountInit(ModelView):
     'Update Chart Account from Template Init'
     _name = 'account.account.update_chart_account.init'
     _description = __doc__
-    account = fields.Many2One('account.account', 'Account',
+    account = fields.Many2One('account.account', 'Root Account',
             required=True, domain=[('parent', '=', False)])
 
 UpdateChartAccountInit()
 
 
+class UpdateChartAccountStart(ModelView):
+    'Update Chart Account from Template Start'
+    _name = 'account.account.update_chart_account.start'
+    _description = __doc__
+
+UpdateChartAccountStart()
+
+
 class UpdateChartAccount(Wizard):
     'Update Chart Account from Template'
     _name = 'account.account.update_chart_account'
@@ -1960,15 +1976,18 @@ class UpdateChartAccount(Wizard):
                 'object': 'account.account.update_chart_account.init',
                 'state': [
                     ('end', 'Cancel', 'tryton-cancel'),
-                    ('update_account', 'Ok', 'tryton-ok', True),
+                    ('start', 'Ok', 'tryton-ok', True),
                 ],
             },
         },
-        'update_account': {
+        'start': {
+            'actions': ['_action_update_account'],
             'result': {
-                'type': 'action',
-                'action': '_action_update_account',
-                'state': 'end',
+                'type': 'form',
+                'object': 'account.account.update_chart_account.start',
+                'state': [
+                    ('end', 'Ok', 'tryton-ok', True),
+                ],
             },
         },
     }
@@ -2380,7 +2399,7 @@ class AgedBalance(Report):
                         'JOIN account_account a ON (l.account = a.id) '
                     'WHERE l.party IS NOT NULL '\
                         'AND a.active ' \
-                        'AND a.kind IN ('+ ','.join('%s' for i in kind) + ") "\
+                        'AND a.kind IN ('+ ','.join(('%s',) * len(kind)) + ") "\
                         'AND l.reconciliation IS NULL ' \
                         'AND a.company = %s ' \
                         'AND '+ term_query+\
